@@ -11,9 +11,6 @@ class Worker(object):
         print ins
         while 1:
             task =  self.tq.GET_TASK()
-            print task
-            if not task:
-                continue
             key, method, args = task
             func = getattr(ins, method, None)
             if func:
@@ -48,6 +45,6 @@ def run():
     from Corellia.worker import WorkerPool
     import Husky
     from ..config import config
-    Worker(config.host, "Briareus", pickler=Husky, serialize=False).run(Runtime)
+    Worker(config.host, "Briareus", pickler=Husky, serialize=True).run(Runtime)
 
 
